@@ -3,7 +3,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef TESTENTRY_H
 #define TESTENTRY_H
 
@@ -17,19 +16,19 @@ class TestEntry
 {
 public:
     enum ErrorType {
-        SpellingMistake       =  0x01, /** < misspelled */
-        CapitalizationMistake =  0x02, /** < capitalization error (whAt) */
-        AccentMistake         =  0x04, /** < an accent is missing or wrong (é) */
-        PunctuationMistake    =  0x08, /** < punctuation mistake (doesnt) */
-        ArticleWrong          =  0x10, /** < solution is correct with the article interchanged */
-        ArticleMissing        =  0x20, /** < solution is correct with the article missing*/
-        FalseFriend           =  0x40, /** < a false friend */
-        Synonym               =  0x80, /** < a synonym (may be correct) */
-        Empty                 =  0x100, /** < empty answer string */
-        UnrelatedWord         =  0x200, /** < a valid word but no connection to the solution */
-        Incomplete            =  0x400, /** < the part that was entered is right, but not complete */
-        Correct               =  0x800, /** < no error, solution was right */
-        Wrong                 =  0x1000  /** < some error, solution was somehow wrong check other bits */
+        SpellingMistake = 0x01, /** < misspelled */
+        CapitalizationMistake = 0x02, /** < capitalization error (whAt) */
+        AccentMistake = 0x04, /** < an accent is missing or wrong (é) */
+        PunctuationMistake = 0x08, /** < punctuation mistake (doesnt) */
+        ArticleWrong = 0x10, /** < solution is correct with the article interchanged */
+        ArticleMissing = 0x20, /** < solution is correct with the article missing*/
+        FalseFriend = 0x40, /** < a false friend */
+        Synonym = 0x80, /** < a synonym (may be correct) */
+        Empty = 0x100, /** < empty answer string */
+        UnrelatedWord = 0x200, /** < a valid word but no connection to the solution */
+        Incomplete = 0x400, /** < the part that was entered is right, but not complete */
+        Correct = 0x800, /** < no error, solution was right */
+        Wrong = 0x1000 /** < some error, solution was somehow wrong check other bits */
     };
 
     Q_DECLARE_FLAGS(ErrorTypes, ErrorType)
@@ -60,13 +59,13 @@ public:
      * In conjugation mode, use this tense for the entry.
      */
     QString conjugationTense() const;
-    void setConjugationTense(const QString& tense);
+    void setConjugationTense(const QString &tense);
 
     /**
      * In conjugation mode, use these pronouns for the entry.
      */
     QList<KEduVocWordFlags> conjugationPronouns() const;
-    void setConjugationPronouns(const QList<KEduVocWordFlags>& flags);
+    void setConjugationPronouns(const QList<KEduVocWordFlags> &flags);
 
     void setLastErrors(ErrorTypes errorTypes);
     ErrorTypes lastErrors();
@@ -74,10 +73,13 @@ public:
     void setLastPercentage(double percent);
     double lastPercentage();
 
-    void addUserAnswer(const QString& answer) {
-        if (!answer.isEmpty()) m_userAnswers.append(answer);
+    void addUserAnswer(const QString &answer)
+    {
+        if (!answer.isEmpty())
+            m_userAnswers.append(answer);
     }
-    QStringList userAnswers() {
+    QStringList userAnswers()
+    {
         return m_userAnswers;
     }
 
@@ -94,15 +96,14 @@ public:
     grade_t practiceModeDependentMaxPreGrade() const;
 
 private:
-    grade_t practiceModeDependentGrade(std::function<grade_t(KEduVocText)> gradeFunc,
-                                       std::function<grade_t(grade_t, grade_t)> minMaxFunc) const;
+    grade_t practiceModeDependentGrade(std::function<grade_t(KEduVocText)> gradeFunc, std::function<grade_t(grade_t, grade_t)> minMaxFunc) const;
 
 private:
     /// the entry itself
     KEduVocExpression *m_entry;
 
-    int  m_languageFrom;   // Index of the language this entry is from
-    int  m_languageTo;     // Index of the language this entry is from
+    int m_languageFrom; // Index of the language this entry is from
+    int m_languageTo; // Index of the language this entry is from
 
     // These are for the current entry only, so that we can display
     // statistics about it after the training session is finished..
@@ -111,8 +112,8 @@ private:
     int m_statisticBadCount;
     int m_answeredCorrectInSequence;
     bool m_correctAtFirstAttempt;
-    bool m_shouldChangeGrades;  // Set to true when grades should be changed after the practice
-    bool m_isUnseenQuestion;    // Is set to true for questions never seen before.
+    bool m_shouldChangeGrades; // Set to true when grades should be changed after the practice
+    bool m_isUnseenQuestion; // Is set to true for questions never seen before.
 
     double m_lastPercentage;
     ErrorTypes m_lastError;
@@ -120,7 +121,7 @@ private:
     QStringList m_userAnswers;
 
     //! Only affects conjugation training.
-    QString                 m_conjugationTense;
+    QString m_conjugationTense;
     //! Only affects conjugation training.
     QList<KEduVocWordFlags> m_conjugationPronouns;
 };
