@@ -102,7 +102,7 @@ void KGameThemeSelectorPrivate::findThemes(const QString &initialSelection)
     QStringList themePaths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
                                                        QCoreApplication::applicationName() + '/' + lookupDirectory + '/',
                                                        QStandardPaths::LocateDirectory);
-    for (const QString &dir : qAsConst(themePaths)) {
+    for (const QString &dir : std::as_const(themePaths)) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.desktop"), QDir::NoFilter, QDirIterator::Subdirectories);
         while (it.hasNext()) {
             it.next();
@@ -111,7 +111,7 @@ void KGameThemeSelectorPrivate::findThemes(const QString &initialSelection)
     }
 
     bool initialFound = false;
-    for (const QString &file : qAsConst(themesAvailable)) {
+    for (const QString &file : std::as_const(themesAvailable)) {
         QString themePath = lookupDirectory + '/' + file;
         KGameTheme *atheme = new KGameTheme(groupName);
 
@@ -137,7 +137,7 @@ void KGameThemeSelectorPrivate::findThemes(const QString &initialSelection)
     if (!initialFound) {
         // TODO change this if we ever change KGameTheme::loadDefault
         QString defaultPath = QStringLiteral("themes/default.desktop");
-        for (KGameTheme *theme : qAsConst(themeMap)) {
+        for (KGameTheme *theme : std::as_const(themeMap)) {
             if (theme->path().endsWith(defaultPath)) {
                 const QList<QListWidgetItem *> itemList = ui.themeList->findItems(theme->themeProperty(QStringLiteral("Name")), Qt::MatchExactly);
                 // never can be != 1 but better safe than sorry
